@@ -1,3 +1,10 @@
+from django.shortcuts import render_to_response
+from django.template import RequestContext
+from django.core import serializers
+from django.utils import simplejson
+from django.http import HttpResponse
+from django import forms
+
 def model_to_modelform(model):
     meta = type('Meta', (), { "model":model, })
     modelform_class = type('modelform', (forms.ModelForm,), {"Meta": meta})
@@ -13,8 +20,8 @@ def delete(obj):
     result = simplejson.dumps({"status":"deleted"})
     return HttpResponse(result, mimetype='application/json')
 
-def save(obj):
-    data = simplejson.loads(request.POST.get("data"))
+def save(obj, data):
+    data = simplejson.loads(data)
     modelform_class = model_to_modelform(obj.__class__)
     modelform = modelform_class(data, instance=obj)    
     if modelform.is_valid():
